use tauri::App;
use tauri::TitleBarStyle;
use tauri::{WebviewUrl, WebviewWindowBuilder};

pub fn setup_window(app: &mut App) -> Result<(), Box<dyn std::error::Error>> {
    let win_builder = WebviewWindowBuilder::new(app, "main", WebviewUrl::default())
        .inner_size(480.0, 360.0)
        .title("Haystack")
        .hidden_title(true)
        .resizable(false);

    //
    #[cfg(target_os = "macos")]
    let win_builder = win_builder.title_bar_style(TitleBarStyle::Transparent);

    let window = win_builder.build().unwrap();

    #[cfg(target_os = "macos")]
    {
        use cocoa::appkit::{NSColor, NSWindow};
        use cocoa::base::{id, nil};

        let ns_window = window.ns_window().unwrap() as id;
        unsafe {
            let bg_color = NSColor::colorWithRed_green_blue_alpha_(
                nil,
                245.0 / 255.0,
                245.0 / 255.0,
                245.0 / 255.0,
                1.0,
            );
            ns_window.setBackgroundColor_(bg_color);
        }
    }

    Ok(())
}
